@@ -10,7 +10,7 @@
   <title>MagickCore, C API: Get the Version and Copyrights @ ImageMagick</title>
   <meta name="application-name" content="ImageMagick">
   <meta name="description" content="Use ImageMagick® to create, edit, compose, convert bitmap images. With ImageMagick you can resize your image, crop it, change its shades and colors, add captions, among other operations.">
-  <meta name="application-url" content="https://www.imagemagick.org">
+  <meta name="application-url" content="https://imagemagick.org">
   <meta name="generator" content="PHP">
   <meta name="keywords" content="magickcore, c, api:, get, the, version, copyrights, ImageMagick, PerlMagick, image processing, image, photo, software, Magick++, OpenMP, convert">
   <meta name="rating" content="GENERAL">
@@ -23,7 +23,7 @@
   <meta name="distribution" content="Global">
   <meta name="magick-serial" content="P131-S030410-R485315270133-P82224-A6668-G1245-1">
   <meta name="google-site-verification" content="_bMOCDpkx9ZAzBwb2kF3PRHbfUUdFj2uO8Jd1AXArz4">
-  <link href="https://www.imagemagick.org/api/version.php" rel="canonical">
+  <link href="https://imagemagick.org/api/version.php" rel="canonical">
   <link href="https://imagemagick.org/image/wand.png" rel="icon">
   <link href="https://imagemagick.org/image/wand.ico" rel="shortcut icon">
   <link href="https://imagemagick.org/assets/magick-css.php" rel="stylesheet">
@@ -57,7 +57,7 @@
         <a class="nav-link" href="https://imagemagick.org/script/develop.php">Develop</a>
       </li>
       <li class="nav-item">
-        <a class="nav-link" target="_blank" href="https://www.imagemagick.org/discourse-server/">Community</a>
+        <a class="nav-link" target="_blank" href="https://imagemagick.org/discourse-server/">Community</a>
       </li>
     </ul>
     <form class="form-inline my-2 my-lg-0" action="../script/search.php">
@@ -83,7 +83,7 @@
 <div class="magick-header">
 <p class="text-center"><a href="version.php#GetMagickCopyright">GetMagickCopyright</a> &bull; <a href="version.php#GetMagickDelegates">GetMagickDelegates</a> &bull; <a href="version.php#GetMagickFeatures">GetMagickFeatures</a> &bull; <a href="version.php#GetMagickHomeURL">GetMagickHomeURL</a> &bull; <a href="version.php#GetMagickLicense">GetMagickLicense</a> &bull; <a href="version.php#GetMagickPackageName">GetMagickPackageName</a> &bull; <a href="version.php#GetMagickQuantumDepth">GetMagickQuantumDepth</a> &bull; <a href="version.php#GetMagickQuantumRange">GetMagickQuantumRange</a> &bull; <a href="version.php#GetMagickReleaseDate">GetMagickReleaseDate</a> &bull; <a href="version.php#GetMagickSignature">GetMagickSignature</a> &bull; <a href="version.php#GetMagickVersion">GetMagickVersion</a> &bull; <a href="version.php#ListMagickVersion">ListMagickVersion</a></p>
 
-<h2><a href="http://www.imagemagick.org/api/MagickCore/version_8c.html" id="GetMagickCopyright">GetMagickCopyright</a></h2>
+<h2><a href="https://imagemagick.org/api/MagickCore/version_8c.html" id="GetMagickCopyright">GetMagickCopyright</a></h2>
 
 <p>GetMagickCopyright() returns the ImageMagick API copyright as a string.</p>
 
@@ -93,7 +93,7 @@
 const char *GetMagickCopyright(void)
 </pre>
 
-<h2><a href="http://www.imagemagick.org/api/MagickCore/version_8c.html" id="GetMagickDelegates">GetMagickDelegates</a></h2>
+<h2><a href="https://imagemagick.org/api/MagickCore/version_8c.html" id="GetMagickDelegates">GetMagickDelegates</a></h2>
 
 <p>GetMagickDelegates() returns the ImageMagick delegate libraries.</p>
 
@@ -105,7 +105,7 @@ const char *GetMagickDelegates(void)
 
 <p>No parameters are required.</p>
 
-<h2><a href="http://www.imagemagick.org/api/MagickCore/version_8c.html" id="GetMagickFeatures">GetMagickFeatures</a></h2>
+<h2><a href="https://imagemagick.org/api/MagickCore/version_8c.html" id="GetMagickFeatures">GetMagickFeatures</a></h2>
 
 <p>GetMagickFeatures() returns the ImageMagick features.</p>
 
@@ -117,7 +117,7 @@ const char *GetMagickFeatures(void)
 
 <p>No parameters are required.</p>
 
-<h2><a href="http://www.imagemagick.org/api/MagickCore/version_8c.html" id="GetMagickHomeURL">GetMagickHomeURL</a></h2>
+<h2><a href="https://imagemagick.org/api/MagickCore/version_8c.html" id="GetMagickHomeURL">GetMagickHomeURL</a></h2>
 
 <p>GetMagickHomeURL() returns the ImageMagick home URL.</p>
 
@@ -127,7 +127,7 @@ const char *GetMagickFeatures(void)
 char *GetMagickHomeURL(void)
 </pre>
 
-<h2><a href="http://www.imagemagick.org/api/MagickCore/version_8c.html" id="GetMagickLicense">GetMagickLicense</a></h2>
+<h2><a href="https://imagemagick.org/api/MagickCore/version_8c.html" id="GetMagickLicense">GetMagickLicense</a></h2>
 
 <p>GetMagickLicense() returns the ImageMagick API license as a string.</p>
 
@@ -137,7 +137,7 @@ char *GetMagickHomeURL(void)
 const char *GetMagickLicense(void)
 </pre>
 
-<h2><a href="http://www.imagemagick.org/api/MagickCore/version_8c.html" id="GetMagickPackageName">GetMagickPackageName</a></h2>
+<h2><a href="https://imagemagick.org/api/MagickCore/version_8c.html" id="GetMagickPackageName">GetMagickPackageName</a></h2>
 
 <p>GetMagickPackageName() returns the ImageMagick package name.</p>
 
@@ -149,7 +149,7 @@ const char *GetMagickName(void)
 
 <p>No parameters are required.</p>
 
-<h2><a href="http://www.imagemagick.org/api/MagickCore/version_8c.html" id="GetMagickQuantumDepth">GetMagickQuantumDepth</a></h2>
+<h2><a href="https://imagemagick.org/api/MagickCore/version_8c.html" id="GetMagickQuantumDepth">GetMagickQuantumDepth</a></h2>
 
 <p>GetMagickQuantumDepth() returns the ImageMagick quantum depth.</p>
 
@@ -171,7 +171,7 @@ const char *GetMagickQuantumDepth(size_t *depth)
 
 <dd>  </dd>
 </dl>
-<h2><a href="http://www.imagemagick.org/api/MagickCore/version_8c.html" id="GetMagickQuantumRange">GetMagickQuantumRange</a></h2>
+<h2><a href="https://imagemagick.org/api/MagickCore/version_8c.html" id="GetMagickQuantumRange">GetMagickQuantumRange</a></h2>
 
 <p>GetMagickQuantumRange() returns the ImageMagick quantum range.</p>
 
@@ -193,7 +193,7 @@ const char *GetMagickQuantumRange(size_t *range)
 
 <dd>  </dd>
 </dl>
-<h2><a href="http://www.imagemagick.org/api/MagickCore/version_8c.html" id="GetMagickReleaseDate">GetMagickReleaseDate</a></h2>
+<h2><a href="https://imagemagick.org/api/MagickCore/version_8c.html" id="GetMagickReleaseDate">GetMagickReleaseDate</a></h2>
 
 <p>GetMagickReleaseDate() returns the ImageMagick release date.</p>
 
@@ -205,7 +205,7 @@ const char *GetMagickReleaseDate(void)
 
 <p>No parameters are required.</p>
 
-<h2><a href="http://www.imagemagick.org/api/MagickCore/version_8c.html" id="GetMagickSignature">GetMagickSignature</a></h2>
+<h2><a href="https://imagemagick.org/api/MagickCore/version_8c.html" id="GetMagickSignature">GetMagickSignature</a></h2>
 
 <p>GetMagickSignature() returns a signature that uniquely encodes the MagickCore libary version, quantum depth, HDRI status, OS word size, and endianness.</p>
 
@@ -227,7 +227,7 @@ unsigned int GetMagickSignature(const StringInfo *nonce)
 
 <dd>  </dd>
 </dl>
-<h2><a href="http://www.imagemagick.org/api/MagickCore/version_8c.html" id="GetMagickVersion">GetMagickVersion</a></h2>
+<h2><a href="https://imagemagick.org/api/MagickCore/version_8c.html" id="GetMagickVersion">GetMagickVersion</a></h2>
 
 <p>GetMagickVersion() returns the ImageMagick API version as a string and as a number.</p>
 
@@ -249,7 +249,7 @@ const char *GetMagickVersion(size_t *version)
 
 <dd>  </dd>
 </dl>
-<h2><a href="http://www.imagemagick.org/api/MagickCore/version_8c.html" id="ListMagickVersion">ListMagickVersion</a></h2>
+<h2><a href="https://imagemagick.org/api/MagickCore/version_8c.html" id="ListMagickVersion">ListMagickVersion</a></h2>
 
 <p>ListMagickVersion() identifies the ImageMagick version by printing its attributes to the file.  Attributes include the copyright, features, and delegates.</p>
 
